.jp-Ksmm {
    color: var(--jp-ui-font-color1);
    background: var(--jp-layout-color1);
    display: flex;
    overflow: auto;
    position: absolute;
    width: 100%;
    left: 0;
}

div.card{
    margin: 12px;

}
